Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorddunne2009-04-15 17:26:16 +0000
committerddunne2009-04-15 17:26:16 +0000
commitf1cba25cc4a57052f71531ad996b8da07ac9a446 (patch)
treefaf3a5a3ec9b7a25f29ae00fbb73660b9b8ca80e /org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java
parent416c3ce515f8f7504c37a51a81aa78d4f58f1444 (diff)
downloadorg.eclipse.osee-f1cba25cc4a57052f71531ad996b8da07ac9a446.tar.gz
org.eclipse.osee-f1cba25cc4a57052f71531ad996b8da07ac9a446.tar.xz
org.eclipse.osee-f1cba25cc4a57052f71531ad996b8da07ac9a446.zip
Diffstat (limited to 'org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java')
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java
index 1eafe0e3bd3..42fd3e54bad 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/util/AtsBranchManager.java
@@ -389,11 +389,11 @@ public class AtsBranchManager {
* @return true if there is at least one destination branch committed to
*/
public boolean isCommittedBranchExists() throws OseeCoreException {
- return (getBranchesCommittedTo().size() > 0);
+ return isAllVersionsToCommitToConfigured() && (getBranchesCommittedTo().size() > 0);
}
/**
* Return true if all commit destination branches have been committed to
*
* @return true
* @throws OseeCoreException
@@ -389,11 +389,11 @@ public class AtsBranchManager {
}
/**
- * Return true if all commit destination branches have been committed to
+ * Return true if all commit destination branches are configured and have been committed to
*
* @return true

Back to the top